@@ -6,7 +6,6 @@ SPDX-License-Identifier: GPL-3.0-or-later
 
 #pragma once
 
-#include "filestatus.h"
 #include <QAbstractListModel>
 
 #include <QList>
@@ -25,8 +24,6 @@ public:
     QVariant data(const QModelIndex &index, int role) const override;
     void append(const QString &data);
 
-    void addFile(const Git::FileStatus &file);
-
 private:
     QList<QPair<QString, QString>> mFiles;
 };
